@@ -197,7 +197,7 @@ sub get_proxy (;$) {
 	our $PROMPT_PROXY;
 	unless (defined $PROMPT_PROXY) {
 	    require urpm::prompt;
-	    $PROMPT_PROXY = new urpm::prompt(
+	    $PROMPT_PROXY = urpm::prompt->new(
 		N("Please enter your credentials for accessing proxy\n"),
 		[ N("User name:"), N("Password:") ],
 		undef,
@@ -943,10 +943,17 @@ sub sync_rel {
     my @result_files = map { $all_options->{dir} . '/' . basename($_) } @$rel_files;
     unlink @result_files if $all_options->{preclean};
 
+    #- The files must be world-readable, else mgaapplet and urpm* commands run as
+    #- a normal user won't be able to read them. We enforce umask here in the case
+    #- where the msec security level is set to 'secure' (which means umask 077)
+    #- or where we are run from a gdm-x-session (mga#24636)
+    my $old_umask = umask 0022;
+
     (my $cwd) = getcwd() =~ /(.*)/;
     eval { _sync_webfetch_raw($urpm, $medium, $rel_files, \@files, $all_options) };
     my $err = $@;
     chdir $cwd;
+    umask $old_umask;
     if (!$err) {
 	$urpm->{log}(N("retrieved %s", $files_text));
 	\@result_files;
@@ -1122,6 +1129,6 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2017 Mageia
+Copyright (C) 2011-2020 Mageia
 
 =cut
