@@ -3,6 +3,7 @@ package urpm::main_loop;
 
 #- Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 #- Copyright (C) 2005-2010 Mandriva SA
+#- Copyright (C) 2011-2020 Mageia
 #-
 #- This program is free software; you can redistribute it and/or modify
 #- it under the terms of the GNU General Public License as published by
@@ -222,6 +223,7 @@ sub _init_common_options {
       callback_open_helper => $callbacks->{open_helper},
       callback_trans => $callbacks->{trans},
       callback_uninst => $callbacks->{uninst},
+      callback_verify => $callbacks->{verify},
       raw_message => 1,
   );
 }
@@ -495,6 +497,8 @@ sub run {
     my (@errors, @formatted_errors);
     $exit_code = 0;
 
+    urpm::select::migrate_forward_rpmdb_db_if_needed($urpm, $state);
+
     my $migrate_back_rpmdb_db_version = 
       $urpm->{root} && urpm::select::should_we_migrate_back_rpmdb_db_version($urpm, $state);
 
@@ -633,6 +637,6 @@ Copyright (C) 1999-2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2015 Mageia
+Copyright (C) 2011-2020 Mageia
 
 =cut
