@@ -28,8 +28,8 @@ our @EXPORT = qw(add2hash_
     put_in_hash
     quotespace
     reduce_pathname
-    remove_internal_name
     same_size_and_mtime
+    uefi_type
     uniq
     uniq_
     unquotespace
@@ -43,7 +43,6 @@ sub max  { my $n = shift; $_ > $n and $n = $_ foreach @_; $n }
 #- quoting/unquoting a string that may be containing space chars.
 sub quotespace		 { my $x = $_[0] || ''; $x =~ s/(\s)/\\$1/g; $x }
 sub unquotespace	 { my $x = $_[0] || ''; $x =~ s/\\(\s)/$1/g; $x }
-sub remove_internal_name { my $x = $_[0] || ''; $x =~ s/\(\S+\)$/$1/g; $x }
 
 sub dirname { local $_ = shift; s|[^/]*/*\s*$||; s|(.)/*$|$1|; $_ || '.' }
 sub basename { local $_ = shift; s|/*\s*$||; s|.*/||; $_ }
@@ -65,7 +64,7 @@ sub reduce_pathname {
     #- clean url to remove any macro (which cannot be solved now).
     #- take care if this is a true url and not a simple pathname.
     my ($host, $dir) = $url =~ m|([^:/]*://[^/]*/)?(.*)|;
-    $host = '' if !defined $host;
+    $host //= '';
 
     #- remove any multiple /s or trailing /.
     #- then split all components of pathname.
@@ -186,7 +185,20 @@ sub uniq_(&@) {
 
 sub output_safe {
     my ($file, $content, $o_backup_ext) = @_;
-    
+
+    #- The file must be world-readable, else mgaapplet and urpm* commands run as
+    #- a normal user won't be able to read it. We enforce umask here in the case
+    #- where the msec security level is set to 'secure' (which means umask 077)
+    #- or where we are run from a gdm-x-session (mga#24636)
+    my $old_umask = umask 0022;
+    my $retval = output_safe_($file, $content, $o_backup_ext);
+    umask $old_umask;
+    $retval;
+}
+
+sub output_safe_ {
+    my ($file, $content, $o_backup_ext) = @_;
+
     open(my $f, '>', "$file.new") or return;
     print $f $content or return;
     close $f or return;
@@ -215,6 +227,16 @@ sub append_to_file {
     1;
 }
 
+#- return the UEFI machine type short name
+sub uefi_type() {
+    if (-e '/sys/firmware/efi/fw_platform_size') {
+        # No support for ARM yet
+        cat_('/sys/firmware/efi/fw_platform_size') =~ /32/ ? 'ia32' : 'x64';
+    } else {
+        'none';
+    }
+}
+
 1;
 
 
@@ -234,4 +256,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
